@@ -184,7 +184,7 @@ output$ui_Manage <- renderUI({
         condition = "input.dataType != 'clipboard' &&
                      input.dataType != 'examples'",
         conditionalPanel(
-          "input.dataType == 'csv' | input.dataType == 'url_csv'",
+          "input.dataType == 'csv' || input.dataType == 'url_csv'",
           with(tags, table(
             td(checkboxInput("man_header", "Header", TRUE)),
             td(HTML("&nbsp;&nbsp;")),
@@ -288,10 +288,10 @@ output$man_descr_md <- renderUI({
       mode = "markdown",
       theme = getOption("radiant.ace_theme", default = "tomorrow"),
       wordWrap = TRUE,
+      debounce = 0,
       value =  descr_out(r_info[[paste0(input$dataset, "_descr")]], "md"),
       placeholder = "Type text to describe the data using markdown to format it.\nSee http://commonmark.org/help/ for more information",
       vimKeyBinding = getOption("radiant.ace_vim.keys", default = FALSE),
-      debounce = 0,
       tabSize = getOption("radiant.ace_tabSize", 2),
       useSoftTabs = getOption("radiant.ace_useSoftTabs", TRUE),
       showInvisibles = getOption("radiant.ace_showInvisibles", FALSE),
